@@ -4,4 +4,4 @@ from microservice_template_core.tools.logger import logger
 from microservice_template_core.core import Core
 from microservice_template_core.tools.kafka_consumer import KafkaConsumeMessages
 from microservice_template_core.tools.kafka_producer import KafkaProduceMessages
-from microservice_template_core.tools.aerospike import AerospikeClient
+from microservice_template_core.tools.aerospike_client import AerospikeClient
