@@ -6,6 +6,8 @@ class ServiceConfig:
     SERVICE_PORT = os.getenv('SERVICE_PORT', 8081)
     SERVER_NAME = os.getenv('SERVER_NAME', "0.0.0.0")
     URL_PREFIX = os.getenv('URL_PREFIX', '/api/v1')
+    SERVICE_NAMESPACE = os.getenv('SERVICE_NAMESPACE', 'dev')
+    POD_NAME = os.getenv('POD_NAME', '')
     configuration = {}
 
 
@@ -17,8 +19,8 @@ class LoggerConfig:
 
 
 class TracerConfig:
-    JAEGER_SERVER = os.getenv('JAEGER_SERVER', '127.0.0.1')
-    JAEGER_PORT = int(os.getenv('JAEGER_PORT', 6831))
+    AGENT_HOSTNAME = os.getenv('AGENT_HOSTNAME', '127.0.0.1')
+    AGENT_PORT = int(os.getenv('AGENT_PORT', 55680))
 
 
 class FlaskConfig:
